#![no_std]
#![no_main]

#[cfg(not(all(
    not(all(feature = "rp2040", feature = "rp2350")),
    any(feature = "rp2040", feature = "rp2350")
)))]
compile_error!("Enable either feature rp2040 (pico 1) or feature rp2350 (pico 2)");

use core::panic::PanicInfo;

use embassy_executor::Spawner;
use embassy_rp::gpio::{Level, Output};

#[panic_handler]
fn panic(_info: &PanicInfo) -> ! {
    loop {}
}

#[cfg(feature = "rp2350")]
#[link_section = ".start_block"]
#[used]
pub static IMAGE_DEF: embassy_rp::block::ImageDef = embassy_rp::block::ImageDef::secure_exe();

#[embassy_executor::main]
async fn main(_spawner: Spawner) {
    let p = embassy_rp::init(Default::default());

    let mut pin = Output::new(p.PIN_25, Level::High);

    let toggle_led = async {
        loop {
            pin.toggle();
        }
    };

    toggle_led.await;
}
